@@ -1,10 +1,10 @@
-from microapp import Project
+from meteolab import Meteolab
 from .nml2json import NML2Json
 from .e3smtimestat import E3SMTimeStat
 
-class E3SMLab(Project):
+class E3SMlab(Meteolab):
     _name_ = "e3smlab"
-    _version_ = "0.1.3"
+    _version_ = "0.1.4"
     _description_ = "E3SM Analysis Utilities"
     _long_description_ = "Tools for Analysis of E3SM project"
     _author_ = "Youngsung Kim"
